#!/usr/bin
# -*- coding: utf-8 -*-


# #############################################################################
# Ce programme génère automatiquement un fichier .pbs permettant d'exécuter
# un calcul Abaqus.
#
# Il est scindé en trois parties :
# - une partie préparation Abaqus ;
# - une partie demande des ressources ;
# - une partie génération du fichier SLURM.
#
# Il doit pouvoir s'adapter à d'autres programmes : seule les seconde
# et troisième parties étant à modifier.
#
# -----------------------------------------------------------------------------
# Utilisation
# 1. Créez un dossier /tmpdir/<votreLogin>/<votreDossier>
# 2. Placer y le fichier script.py
# 3. Placer y le fichier <votreFichier>.inp
#    Éventuellement ajoutez-y :
#        <votreFichier>.for ou <votreFichier>.f (je ne sais plus...)
# 4. Placez-vous dans /tmpdir/<votreLogin>/<votreDossier>
#    et tapez la commande : python script.py
#
# 5. Laissez vous guider pour l'allocation des ressources
#
# => Le programme génère un fichier .pbs que vous pouvez exécuter directement
#    à la fin du programme, ou bien à la main via
#        qsub fichier_généré.pbs
#
# => Le fichier_généré.slurm génère un répertoire
#        /tmpdir/<votreLogin>/<votreDossier>/$PBS_JOBID
# => Il y recopie les fichiers nécessaires (.inp, .f, .pbs, ...)
# => Enfin il exécute Abaqus
#
#    Les fichiers de résultats seront dans
#        /tmpdir/<votreLogin>/<votreDossier>/$PBS_JOBID
#
# 6. Pour vérifier que tout va bien :
#      qstat -u <votreLogin>
#      qstat -n $PBS_JOBID
#      ssh leNomDeLUnDesNoeudsDeCalcul
#          (renvoyé par la commande précédente)
#      top
#          (vous devriez voir des pre.exe, package_dp.exe, explicit_dp.exe...)
#
# -----------------------------------------------------------------------------
# License GNU/GPL
# Copyright 2014 Calmip
#
# Dernière modification : le vendredi 17 mars 2017 par Steven MARGUET pour l'ICA
# #############################################################################


# #############################################################################
# VOCABULAIRE
#
# Un noeud : ensemble de microprocesseurs/sockets partageant leur mémoire vive
#
# Un socket : un microprocesseur
#
# Un coeur : une unité de calcul (un microprocesseur/socket
#                                 peut posséder plusieurs coeurs)
#
# Une "queue" : à compléter
#
# Ram : mémoire vive
# #############################################################################



# Automatisation ==============================================================
INP_FILE = None # "nom_fichier.inp"
FORTRAN = None # à choisir dans (None, "o", "n")
FORTRAN_FILE = None # "nom_fichier.f"
RESTART = None # à choisir dans (None, "o", "n")
MACHINE = None # "nom_queue"
MACHINE_CPUS = None # entier
CLEAN = None # à choisir dans (None, "o", "n")
CHANGER_TEMPS = None # à choisir dans (None, "o", "n")
TEMPS_MAX_H = 24*5 # en heures être humain
AFFICHER = "o" # à choisir dans (None, "o", "n")
EXECUTER = None à choisir dans (None, "o", "n")
USER_RELATIVE_FOLDER_FOR_WORKDIR = "steven" # sans / à la fin !


# À modifier par l'utilisateur ================================================
E_MAIL = "steven.marguet@univ-tlse3.fr"
LOGIN = ""

ABAQUS_EXEC = "abq2016" # "abq6135" # "abq6112"
ABAQUS_PATH = "/usr/local/abaqus/Commands" # sans / à la fin !

FICHIERS_A_CONSERVER_SI_NETTOYAGE = (".pbs", ".inp", ".f")
FICHIERS_NECESSAIRES_POUR_RESTART = (".odb", ".res", ".abq", ".mdl",
                                     ".pac", ".stt", ".prt", ".sel")
LARGEUR_TERMINAL = 80
ABAQUS_JOB = "explicit" # à choisir dans ("explicit", "standard")
ABAQUS_DIR = {"abq2016": "abaqus_2016",
              "abq6135": "6.13-5",
              "abq6112": "6.11-2"}
ABAQUS_ENV = {"abq2016": "abaqus_2016/linux_a64/SMA",
              "abq6135": "6.13-5/SMA",
              "abq6112": "6.11-2"}
ABAQUS_MOD = {"abq2016": ("module purge", "module load intel/09.1","module load intelmpi/13.2", "module load intel/12.1.5" )}

ABAQUS_DIR = ABAQUS_DIR[ABAQUS_EXEC]
ABAQUS_ENV = ABAQUS_ENV[ABAQUS_EXEC]



# Constantes ==================================================================
# tuple pour conserver l'ordre (modifié ultérieurement en dictionnaire)
QUEUES_LIST = (("mono", {"machine":"olympe",
                         "noeuds":(1,),
                         "coeursParSocket":18,
                         "socketsParNoeud":2,
                         "coeursSelectionnables":range(1,19,1),
                         "ramParSocket":90.0, # en GB - 32 en vrai mais on prend de la marge
                         "exclusif":"non",
                         "hyperthreading":"oui",
                         "maxTempsCalculHumain":400,
                         "jobParUtilisateur":3}),
               ("noeud", {"machine":"olympe",
                          "noeuds":(1,),
                          "coeursParSocket":18,
                          "socketsParNoeud":2,
                          "coeursSelectionnables":(36,),
                          "ramParSocket":90.0, # en GB
                          "exclusif":"oui",
                          "hyperthreading":"oui",
                          "maxTempsCalculHumain":250,
                          "jobParUtilisateur":2}),
               ("noeud5", {"machine":"olympe",
                           "noeuds":range(2,6,1),
                           "coeursParSocket":18,
                           "socketsParNoeud":2,
                           "coeursSelectionnables":range(72,181,36),
                           "ramParSocket":90.0, # en GB
                           "exclusif":"oui",
                           "hyperthreading":"oui",
                           "maxTempsCalculHumain":150,
                           "jobParUtilisateur":2}),
               ("noeud10", {"machine":"olympe",
                            "noeuds":range(6,11,1),
                            "coeursParSocket":18,
                            "socketsParNoeud":2,
                            "coeursSelectionnables":range(216,361,36),
                            "ramParSocket":90.0, # en GB
                            "exclusif":"oui",
                            "hyperthreading":"oui",
                            "maxTempsCalculHumain":110,
                            "jobParUtilisateur":2}),
               ("noeud20", {"machine":"olympe",
                            "noeuds":range(11,21,1),
                            "coeursParSocket":18,
                            "socketsParNoeud":2,
                            "coeursSelectionnables":range(396,721,36),
                            "ramParSocket":90.0, # en GB
                            "exclusif":"oui",
                            "hyperthreading":"oui",
                            "maxTempsCalculHumain":75,
                            "jobParUtilisateur":1}),
               ("noeud40", {"machine":"olympe",
                            "noeuds":range(21,41,1),
                            "coeursParSocket":18,
                            "socketsParNoeud":2,
                            "coeursSelectionnables":range(756,1441,36),
                            "ramParSocket":90.0, # en GB
                            "exclusif":"oui",
                            "hyperthreading":"oui",
                            "maxTempsCalculHumain":36,
                            "jobParUtilisateur":1}),
               ("noeud50", {"machine":"olympe",
                            "noeuds":range(41,51,1),
                            "coeursParSocket":18,
                            "socketsParNoeud":2,
                            "coeursSelectionnables":range(1476,1801,20),
                            "ramParSocket":90.0, # en GB
                            "exclusif":"oui",
                            "hyperthreading":"oui",
                            "maxTempsCalculHumain":24,
                            "jobParUtilisateur":1}),
               ("visu", {"machine":"visu",
                         "noeuds":range(1,),
                         "coeursParSocket":18,
                         "socketsParNoeud":2,
                         "coeursSelectionnables":range(1,37,1),
                         "ramParSocket":180.0, # en GB
                         "exclusif":"non",
                         "hyperthreading":"oui",
                         "maxTempsCalculHumain":4,
                         "jobParUtilisateur":1}))

GIGA_2_MEGA = 1024
DELTA_RAM_PAR_COEUR = 0.1 # nombre de GB de RAM à enlever à la valeur réelle
                          # par coeur pour éviter les problèmes de conversion


# =============================================================================
# PREMIÈRE PARTIE : ABAQUS
# =============================================================================

# Vérification préliminaire de la présence d'un fichier d'entrée
import os
import sys

inputFiles = []
fortranFiles = []

inputFile = False
abaqusEnvFile = False

cwd = os.getcwd()
files = os.listdir(cwd)
for file in files:
    if file[-4:].lower() == ".inp":
        inputFile = True
        inputFiles.append(file)
    elif file[-2:].lower() == ".f":
        fortranFiles.append(file)


# Pour lecture directe du fichier INP à partir du terminal
print inputFiles
if len(sys.argv) > 1:
    INP_FILE = sys.argv[1]
    if not (INP_FILE in inputFiles):
        print "Le fichier .inp spécifié en ligne de commande (" + \
              inp + ") n'est pas dans le dossier."

if not inputFile:
    print "Il doit y avoir un fichier d'entrée .inp dans le dossier %s" \
           % (cwd,)
    exit(1)


# Fichier .inp
print "\n"
print "=" * LARGEUR_TERMINAL
print "Sélection des fichiers d'entrée, nettoyage éventuel"
print "=" * LARGEUR_TERMINAL

if INP_FILE in inputFiles:
    inputFileName = INP_FILE
    print "Fichier d'entrée : " + inputFileName
else:
    msg = "\nFichier d'entrée (.inp) :\n  [ "
    for ifile in inputFiles:
        msg += ifile + " ; "
    msg = msg[:-2] + "]\n>>> "

    inputFileExists = False
    while not inputFileExists:
        inputFileName = raw_input(msg)
        inputFileExists = os.path.isfile(inputFileName)
        if not inputFileExists:
            print "Le fichier spécifié n'existe pas..."
        if not inputFileName[-4:] == ".inp":
            print "Le fichier doit avoir '.inp' pour extension..."

a = len(inputFileName) - 4


# Fichier pour programme utilisateur (Fortran)
if FORTRAN == "o":
    choix = "o"
    fortranFile = FORTRAN_FILE
elif FORTRAN == "n":
    choix = "n"
    fortranFile = None
else:
    fortranFile = False
    msg =  "\nSouaitez-vous spécifier un fichier Fortran (o/n) ?\n>>> "
    choix = "a"
    while not choix.lower() in ("o", "n"):
        choix = raw_input(msg)
        choix = choix.lower()

if choix == "o":
    if FORTRAN == "o":
        fortranFileName = FORTRAN_FILE
        fortranFileExists = True
    else:
        fortranFile = True
        fortranFileExists = False

    if len(fortranFiles) == 0:
        print "\nDésolé, il n'y a pas de fichier .f dans le dossier :" + \
               "\n  %s" % (cwd,)
        exit(1)

    msg = "\nFichier Fortran (.f) :\n  [ "
    for ffile in fortranFiles:
        msg += ffile + " ; "
    msg = msg[:-2] + "]\n>>> "

    while not fortranFileExists:
        fortranFileName = raw_input(msg)
        fortranFileExists = os.path.isfile(fortranFileName)
        if not fortranFileExists:
            print "Le fichier spécifié n'existe pas..."
        if not fortranFileName[-2:] == ".f":
            print "Le fichier doit avoir '.f' pour extension..."


# Restart
if RESTART == "o":
    choix = "o"
elif RESTART == "n":
    choix = "n"
else:
    msg = "\nCe calcul est-il un 'RESTART' d'un précédent calcul (o/n) ?\n>>> "
    choix = None
    while not choix in ("o", "n"):
        choix = raw_input(msg)
        choix = choix.lower()

if choix == "o":
    restart = True
    print "\n" + "*" * LARGEUR_TERMINAL
    print "ATTENTION : vous devez impérativement choisir le même nombre" + \
           " de coeurs que pour le calcul initial."
    print "*" * LARGEUR_TERMINAL
    FAC = FICHIERS_A_CONSERVER_SI_NETTOYAGE \
        + FICHIERS_NECESSAIRES_POUR_RESTART
else:
    restart = False
    FAC = FICHIERS_A_CONSERVER_SI_NETTOYAGE



# Nettoyage
files = os.getcwd()
files = os.listdir(files)
filesToRemove = []
for file in files:
    if file[:a] == inputFileName[:-4] and \
       file[-4:] not in FAC:
        filesToRemove.append(file)

if CLEAN == "o":
    if len(filesToRemove) > 0:
        if len(filesToRemove) == 1:
            msg = "\nVoulez-vous supprimer le fichier :"
        else:
            msg = "\nVoulez-vous supprimer les fichiers (o/n) ?"
        for file in filesToRemove:
            msg += "\n- " + file
        msg += "\n>>> "

        clean = None
        while not clean in ("o","n"):
            clean = raw_input(msg)
            clean = clean.lower()

        if clean == "o":
            for file in filesToRemove:
                os.remove(file)
                print "- " + file + " supprimé"




# =============================================================================
# SECONDE PARTIE : DEMANDE DES RESSOURCES
# =============================================================================
print "\n"
print "=" * LARGEUR_TERMINAL
print "Réservation des ressources"
print "=" * LARGEUR_TERMINAL
print "\n"



print "+-----------+------+------+------+------+------------+-----------+-----+-----+"
print "|>>>      VERSION MODIFIÉE POUR UTILISER TOUS LES COEURS D'UN NOEUD       <<<|"
print "+-----------+------+------+------+------+------------+-----------+-----+-----+"
print "|     queue | minN | maxN | minC | maxC | ram/C (Gb) | maxWT (h) |   E |  HT |"
print "+-----------+------+------+------+------+------------+-----------+-----+-----+"
for key, val in QUEUES_LIST:
    minNoeuds = min(val["noeuds"])
    maxNoeuds = max(val["noeuds"])
    minCoeurs = min(val["coeursSelectionnables"])
    maxCoeurs = max(val["coeursSelectionnables"])
    ramParCoeur = val["ramParSocket"] // val["coeursParSocket"]

    print "| %9s | %4i | %4i | %4i | %4i | %10i | %9i | %3s | %3s |" % \
          (key,
           minNoeuds, maxNoeuds,
           minCoeurs, maxCoeurs,
           ramParCoeur, val["maxTempsCalculHumain"],
           val["exclusif"], val["hyperthreading"])
print "+-----------+------+------+------+------+------------+-----------+-----+-----+"

del(minNoeuds, maxNoeuds, minCoeurs, maxCoeurs)

# Transformation du tuple en dictionnaire
QUEUES = {}
for key, val in QUEUES_LIST:
    QUEUES[key] = val


# Type de queue
if MACHINE:
    queue = MACHINE
else:
    msg = "\nQuel type de calcul souhaitez-vous lancer ("
    for key in QUEUES_LIST:
        msg += key[0] + "/"
    msg = msg[:-1] + ") ?\n>>> "
    queue = None
    while not queue in QUEUES.keys():
        queue = raw_input(msg)


jobtype = queue
queue = QUEUES[queue]

minNoeuds = min(queue["noeuds"])
maxNoeuds = max(queue["noeuds"])
minCoeurs = min(queue["coeursSelectionnables"])
maxCoeurs = max(queue["coeursSelectionnables"])
ramParSocket = queue["ramParSocket"]
coeursParSocket = queue["coeursParSocket"]
socketsParNoeud = queue["socketsParNoeud"]
coeursSelectionnables = queue["coeursSelectionnables"]
tempsMax = queue["maxTempsCalculHumain"]

coeursParNoeud = coeursParSocket * socketsParNoeud
ramParNoeud = ramParSocket * socketsParNoeud
ramParCoeur = float(ramParSocket) / coeursParSocket


# Nombre de coeurs
if MACHINE_CPUS:
    coeurs = MACHINE_CPUS
else:
    coeurs = None
    if jobtype == "mono":
        msg = "\nDe combien de coeurs physiques souhaitez-vous disposer ?"
        msg += "\nVous pouvez choisir entre " + str(minCoeurs)
        msg += " et " + str(maxCoeurs) + " cœurs :"
        msg += "\n>>> "

        while not coeurs in range(minCoeurs, maxCoeurs+1, 1):
            coeurs = raw_input(msg)
            try:
                coeurs = int(coeurs)
            except:
                pass

    elif jobtype == "noeud":
        nnn = coeursSelectionnables[-1]
        msg = "\nAvec le type de calcul 'noeud',"
        msg += " vous disposez de " + str(nnn) + " coeurs physiques."
        print msg
        coeurs = nnn

    else:
        msg = "\nDe combien de coeurs physiques souhaitez-vous disposer ?"
        msg += "\nVous pouvez choisir parmis :\n  "

        for i, n in enumerate(coeursSelectionnables):
            msg += str(n) + "/"
            if (i+1) % 10 == 0:
                msg += "\n  "
        msg = msg[:-1] + "\nce qui revient à utiliser "
        if jobtype in ("uvprod", "uvcalmip"):
            msg += "tous les coeurs d'un socket"
        else:
            msg += "tous les coeurs de tous les sockets d'un noeud"
        msg += "\n>>> "

        while not coeurs in coeursSelectionnables:
            coeurs = raw_input(msg)
            try:
                coeurs = int(coeurs)
            except:
                pass



# Nombre de noeuds et de sockets
sockets = coeurs // coeursParSocket

if coeurs % coeursParSocket != 0:
    sockets += 1

noeuds = coeurs // coeursParNoeud
if coeurs % coeursParNoeud != 0:
    noeuds += 1

msg = "\nVous allez utiliser :\n" \
    + "- %i noeuds ;\n" % (noeuds,) \
    + "- %i sockets ;\n" % (sockets,) \
    + "- %i coeurs.\n" % (coeurs,)
print msg


# Mémoire vive
ramGlobale = coeurs * ramParCoeur # calcul réalisé de cette manière pour être
                                  # adapté à la queue mono

msg = "\nVous disposez actuellement :\n" \
    + "- de %i Gb de mémoire globale ;\n" % (ramGlobale,) \
    + "- soit %i Gb de mémoire par noeud ;\n" % (ramParNoeud,) \
    + "- soit %i Gb de mémoire par socket ;\n" % (ramParSocket,) \
    + "- soit %i Gb de mémoire par coeur." % (ramParCoeur,)



# Temps humain
if CHANGER_TEMPS == "o":
    if not isinstance(TEMPS_MAX_H, int):
        msg = "\nVous disposez actuellement de %i heures 'temps humain' de calcul." \
            % (tempsMax,)
        msg += "\n\nSouhaitez-vous réduire ce temps (o/n) ?\n>>> "
        choix = None
        while not choix in ("o","n"):
            choix = raw_input(msg)
            choix = choix.lower()

        if choix == "o":
            msg = "\nDe combien de temps souhaitez-vous disposer"
            msg += " (le temps doit être inférieur ou égal à"
            msg += " %i heures)" % (tempsMax,)
            msg += " ?\n>>> "

            temps = tempsMax + 1
            while not temps <= tempsMax:
                temps = raw_input(msg)
                try:
                    temps = int(temps)
                except:
                    pass
        else:
            temps = tempsMax
    else:
        msg = "\nVous avez demandé %i heures 'temps humain' de calcul." \
            % (TEMPS_MAX_H, )
        print msg

        msg = "\nDe combien de temps souhaitez-vous disposer"
        msg += " (le temps doit être inférieur ou égal à"
        msg += " %i heures)" % (tempsMax,)
        msg += " ?\n>>> "
        temps = tempsMax + 1
        while not temps <= tempsMax:
            temps = raw_input(msg)
            try:
                temps = int(temps)
            except:
                pass
else:
    if not isinstance(TEMPS_MAX_H, int):
        temps = tempsMax
    else:
        temps = min(tempsMax, TEMPS_MAX_H)

# Récapitulatif
print "\nVous avez demandé un calcul :"
print "- de type : %s ;" % (jobtype,)
print "- sur %i noeuds ;" % (noeuds,)
print "- avec %i sockets ;" % (sockets,)
print "- avec %i coeurs physiques ;" % (coeurs,)
print "- avec %i Gb de mémoire vive globale ;" % (ramGlobale,)
print "  - soit %i Gb de mémoire par noeud ;" % (ramParNoeud,)
print "  - soit %i Gb de mémoire par socket ;" % (ramParSocket,)
print "  - soit %i Gb de mémoire par coeur ;" % (ramParCoeur,)
print "- pendant %i heures en 'temps humain'." % (temps,)







# ==============================================================================
# TROISIÈME PARTIE : FICHIER PBS
# ==============================================================================

# Commande ABAQUS
command = "./" \
        + ABAQUS_EXEC \
        + " interactive" \
        + " job=" + inputFileName[:-4] \
        + " input=" + inputFileName

if fortranFile:
    command += " user=" + fortranFileName[:-2]

if restart:
    command += " oldjob=" + inputFileName[:-4]

command += " cpus=" + str(coeurs)
command += " output_precision=full"

if ABAQUS_JOB == "explicit":
    command += " double=both" \
             + " parallel=domain" \
             + " domains=" + str(coeurs) \
             + " mp_mode=MPI"

elif ABAQUS_JOB == "standard":
    command += " double=both" \
             + " mp_mode=MPI" \
             + " standard_parallel=all"
else:
    raise ValueError, 'ABAQUS_JOB est soit "explicit", soit "standard".'

if jobtype == "mono":
    coeursParNoeud = coeurs
    ramParNoeud = ramParCoeur * coeurs

# Écriture du fichier SLURM
myFile = open(inputFileName[:-3] + "cmd", "w")
myFile.write("#!/bin/bash\n")
myFile.write("#SBATCH -J " + inputFileName[:-4][:10] + "\n")
myFile.write("#SBATCH -N " + str(noeuds) + "\n")
myFile.write("#SBATCH -n " + str(coeurs) + "\n")
myFile.write("#SBATCH --time=%02i:00:00\n" % (temps, ))

if jobtype == "mono":
    myFile.write("#SBATCH --ntasks-per-node=" + str(coeurs) + "\n")
else:
    myFile.write("#SBATCH --ntasks-per-node=36\n")
myFile.write("#SBATCH --ntasks-per-core=1\n")
myFile.write("#SBATCH --mail-user=" + E_MAIL + "\n")
myFile.write("\n")
msg = ABAQUS_MOD[ABAQUS_EXEC][0]
for cmd in ABAQUS_MOD[ABAQUS_EXEC][1:]:
    msg = msg + "\n" + cmd

myFile.write(msg + "\n")
myFile.write("\n")
myFile.write("export OMP_NUM_THREADS=1\n")
myFile.write("\n")
myFile.write("export HERE=`pwd`\n")
if USER_RELATIVE_FOLDER_FOR_WORKDIR:
    myFile.write("export WD=/tmpdir/$LOGNAME/" + USER_RELATIVE_FOLDER_FOR_WORKDIR + "/$SLURM_JOBID\n")
else:
    myFile.write("export WD=/tmpdir/$LOGNAME/$SLURM_JOBID\n")
myFile.write("mkdir $WD\n")
myFile.write("\n")
myFile.write("cp $HERE/" + inputFileName + " $WD\n")
myFile.write("cp $HERE/" + inputFileName[:-3] + "cmd $WD\n")
#myFile.write("cp $HERE/abaqus_v6.env $WD\n")

if fortranFile:
    myFile.write("cp $HERE/" + fortranFileName + " $WD\n")

command += " scratch=$WD"

myFile.write("\n")
myFile.write("cd $WD\n")
myFile.write("\n")
myFile.write("ln -s " + ABAQUS_PATH + "/" + ABAQUS_EXEC + " " + \
                        ABAQUS_EXEC + "\n")
myFile.write("\n")
myFile.write(command)
myFile.write("\n")
myFile.close()


if AFFICHER:
    choix = AFFICHER
else:
    choix = None
    msg = "\nVoulez-vous afficher le fichier " + inputFileName[:-4]
    msg += ".cmd (o/n) ?\n>>> "
while not choix in ("o", "n"):
    choix = raw_input(msg)
    choix = choix.lower()

if choix == "o":
    print "\n" + "*" * LARGEUR_TERMINAL
    os.system("cat " + inputFileName[:-3] + "cmd\n")
    print "*" * LARGEUR_TERMINAL

if EXECUTER:
    choix = EXECUTER
else:
    choix = None
    msg = "\nSouhaitez-vous exécuter sbatch " + inputFileName[:-3]
    msg += "cmd (o/n) ?\n>>> "
while not choix in ("o", "n"):
    choix = raw_input(msg)
    choix = choix.lower()

msg = "\n" + "=" * LARGEUR_TERMINAL
if choix == "n":
    msg += "\nLe job - N'A PAS - été soumis.\n"
elif choix == "o":
    msg += "\nLe job - A - été soumis.\n"
msg += "." * LARGEUR_TERMINAL
msg += "\nRappels :\n"
if choix == "n":
    msg += "- pour lancer le job: sbatch " + inputFileName[:-3] + "cmd\n"
msg += "- pour connaître l'état d'avancement du job : squeue -u LOGIN\n"
msg += "- pour annuler un job                       : scancel JOB_ID\n"
msg += "=" * LARGEUR_TERMINAL + "\n"
print msg

if choix == "o":
    os.system("sbatch " + inputFileName[:-3] + "cmd")

